@@ -28,11 +28,12 @@
 #include <string.h>
 
 /**
- * MateWeatherLocationEntry:
+ * SECTION:location-entry
+ * @Title: MateWeatherLocationEntry
  *
  * A subclass of #GtkEntry that provides autocompletion on
  * #MateWeatherLocation<!-- -->s
- **/
+ */
 
 G_DEFINE_TYPE (MateWeatherLocationEntry, mateweather_location_entry, GTK_TYPE_ENTRY)
 
@@ -466,6 +467,7 @@ mateweather_location_entry_build_model (MateWeatherLocationEntry *entry,
 {
     GtkTreeStore *store = NULL;
 
+    g_return_if_fail (MATEWEATHER_IS_LOCATION_ENTRY (entry));
     entry->top = mateweather_location_ref (top);
 
     store = gtk_tree_store_new (4, G_TYPE_STRING, G_TYPE_POINTER, G_TYPE_STRING, G_TYPE_STRING);
